@@ -12,6 +12,7 @@ import click
 from pkg_resources import resource_string
 from typing import Optional
 from geospock_cli.exceptions import CLIError
+from keyring.errors import NoKeyringError
 
 
 class ConfigReaderAndWriter:
@@ -44,8 +45,11 @@ class ConfigReaderAndWriter:
             raise CLIError("Could not generate configuration entry from provided request address.")
         with open(self.CONFIG_FILE, "w") as config_file_write:
             config_file_write.write(json.dumps(current_config, indent=4))
-        keyring.set_password("geospock", self.profile + "-username", username)
-        keyring.set_password("geospock", self.profile + "-password", password)
+        try:
+            keyring.set_password("geospock", self.profile + "-username", username)
+            keyring.set_password("geospock", self.profile + "-password", password)
+        except NoKeyringError:
+            raise CLIError("No keyring found. Install a keyring and try again.")
 
     def write_logout(self):
         if os.path.exists(self.CONFIG_FILE) and os.path.getsize(self.CONFIG_FILE) > 0:
@@ -66,9 +70,13 @@ class ConfigReaderAndWriter:
 
     @retry(reraise=True, stop=stop_after_attempt(3), wait=wait_fixed(2))
     def get_from_keyring(self):
-        user = keyring.get_password("geospock", self.profile + "-username")
-        password = keyring.get_password("geospock", self.profile + "-password")
-        return user, password
+        try:
+            user = keyring.get_password("geospock", self.profile + "-username")
+            password = keyring.get_password("geospock", self.profile + "-password")
+            return user, password
+        except NoKeyringError:
+            raise CLIError("No keyring found. Install a keyring and try again.")
+
 
     def decode(self):
         try:
